@@ -1,9 +1,9 @@
-#!/usr/bin/env python
-from __future__ import print_function
+#!/usr/bin/env python3
+
 import sys
 
 if len(sys.argv) == 1:
-    print("usage: {} <fasta file or index file> <region size>").format(sys.argv[0])
+    print("usage: {} <fasta file or index file> <region size>".format(sys.argv[0]))
     print("generates a list of freebayes/bamtools region specifiers on stdout")
     print("intended for use in creating cluster jobs")
     exit(1)
