@@ -23,7 +23,7 @@ void Parameters::simpleUsage(char ** argv) {
 }
 
 void Parameters::usage(char** argv) {
-    cout 
+    cout
         << "usage: " << argv[0] << " [OPTION] ... [BAM FILE] ... " << endl
         << endl
         << "Bayesian haplotype-based polymorphism discovery." << endl
@@ -93,7 +93,7 @@ void Parameters::usage(char** argv) {
         << endl
         << "    # naive variant calling: simply annotate observation counts of SNPs and indels" << endl
         << "    freebayes -f ref.fa --haplotype-length 0 --min-alternate-count 1 \\ " << endl
-        << "        --min-alternate-fraction 0 --pooled-continuous --report-monomorphic >var.vcf" << endl
+        << "        --min-alternate-fraction 0 --pooled-continuous --report-monomorphic aln.bam >var.vcf" << endl
         << endl
         << endl
         << "parameters:" << endl
@@ -304,6 +304,8 @@ void Parameters::usage(char** argv) {
         << "                   Skip processing of alignments overlapping positions with coverage >N." << endl
         << "                   This filters sites above this coverage, but will also reduce data nearby." << endl
         << "                   default: no limit" << endl
+        << "   --trim-complex-tail" << endl
+        << "                   Trim complex tails." << endl
         << endl
         << "population priors:" << endl
         << endl
@@ -490,6 +492,7 @@ Parameters::Parameters(int argc, char** argv) {
     minCoverage = 0;
     limitCoverage = 0;
     skipCoverage = 0;
+    trimComplexTail = 0;
     debuglevel = 0;
     debug = false;
     debug2 = false;
@@ -498,7 +501,7 @@ Parameters::Parameters(int argc, char** argv) {
 
     int c; // counter for getopt
 
-    static struct option long_options[] =
+    static const struct option long_options[] =
         {
             {"help", no_argument, 0, 'h'},
             {"version", no_argument, 0, '#'},
@@ -564,6 +567,7 @@ Parameters::Parameters(int argc, char** argv) {
             {"min-coverage", required_argument, 0, '!'},
             {"limit-coverage", required_argument, 0, '+'},
             {"skip-coverage", required_argument, 0, 'g'},
+            {"trim-complex-tail", no_argument, 0, ']'},
             {"genotype-qualities", no_argument, 0, '='},
             {"variant-input", required_argument, 0, '@'},
             {"only-use-input-alleles", no_argument, 0, 'l'},
@@ -665,15 +669,15 @@ Parameters::Parameters(int argc, char** argv) {
             gVCFout = true;
             break;
 
-            // -& BOOL/INT --gvcf-no-chunk BOOL/INT  --gvcf-chunk 
+            // -& BOOL/INT --gvcf-no-chunk BOOL/INT  --gvcf-chunk
         case '&':
             //cerr << "optarg:\t" << optarg << endl;
             if(optarg[0] == 't'){
                 gVCFNoChunk = true;
             } else if (optarg[0] == 'f'){
-                gVCFNoChunk = false; 
+                gVCFNoChunk = false;
             } else {
-                gVCFchunk = atoi(optarg);  
+                gVCFchunk = atoi(optarg);
             }
             break;
 
@@ -722,6 +726,11 @@ Parameters::Parameters(int argc, char** argv) {
             }
             break;
 
+            // --trim-complex-tail
+        case ']':
+            trimComplexTail = true;
+            break;
+
             // -n --use-best-n-alleles
         case 'n':
             if (!convert(optarg, useBestNAlleles)) {
@@ -1083,7 +1092,7 @@ Parameters::Parameters(int argc, char** argv) {
             break;
 
     case '#':
-        
+
         // --version
             cout << "version:  " << VERSION_GIT << endl;
         exit(0);
@@ -1093,13 +1102,13 @@ Parameters::Parameters(int argc, char** argv) {
             usage(argv);
             exit(0);
             break;
- 
+
             // either catch "long options" or
         case '?': // print a suggestion about the most-likely long option which the argument matches
         {
             string bad_arg(argv[optind - 1]);
-            option* opt = &long_options[0];
-            option* closest_opt = opt;
+            const option* opt = &long_options[0];
+            const option* closest_opt = opt;
             int shortest_distance = levenshteinDistance(opt->name, bad_arg);
             ++opt;
             while (opt->name != 0) {
@@ -1120,7 +1129,7 @@ Parameters::Parameters(int argc, char** argv) {
         }
 
     }
- 
+
     // any remaining arguments are considered as bam files
     if (optind < argc) {
         if (useStdin) {
